import React__default, { forwardRef, useState, useMemo, useRef, useImperativeHandle, useLayoutEffect } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import useResizeObserver from '@react-hook/resize-observer';
import { LogoLarge } from './logo-large/logo-large.js';
import styles from './header.module.pcss.js';
import { getNavScheme } from './nav-scheme.js';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { SearchButton } from './search-button/search-button.js';
import { MenuPopup } from './menu-popup/menu-popup.js';
import { LogoSmall } from './logo-small/logo-small.js';
import classNames from 'classnames';
const MENU_POPUP_BREAKPOINT = 640;
const Header = forwardRef(({
  productWebUrl,
  hasSearch = false,
  onSearchClick,
  currentUrl,
  currentTitle,
  className,
  hasBorder = true,
  dropdownTheme = 'dark',
  linkHandler,
  isPlayground,
  isUrlActive
}, forwardedRef) => {
  const [menuPopupExpanded, setMenuPopupExpanded] = useState(false);
  const [isMenuPopupVisible, setIsMenuPopupVisible] = useState(false);
  const items = useMemo(() => getNavScheme(isUrlActive, currentUrl, isPlayground), [isUrlActive, currentUrl, isPlayground]);
  const headerRef = useRef(null);
  useImperativeHandle(forwardedRef, () => headerRef.current);
  useLayoutEffect(() => {
    setIsMenuPopupVisible((headerRef.current?.getBoundingClientRect?.().width ?? 0) <= MENU_POPUP_BREAKPOINT);
  }, [headerRef]);
  useResizeObserver(headerRef, entry => setIsMenuPopupVisible(entry.contentRect.width <= MENU_POPUP_BREAKPOINT));
  return React__default.createElement(ThemeProvider, {
    theme: 'dark'
  }, React__default.createElement("header", {
    ref: headerRef,
    className: classNames(styles.headerMenu, className, {
      [styles.withMenuPopup]: menuPopupExpanded,
      [styles.border]: hasBorder
    })
  }, isMenuPopupVisible && currentTitle && currentUrl && !menuPopupExpanded ? React__default.createElement(LogoSmall, {
    homeTitle: currentTitle,
    homeUrl: currentUrl
  }) : React__default.createElement(LogoLarge, {
    productWebUrl: productWebUrl
  }), !isMenuPopupVisible && React__default.createElement(HorizontalMenu, {
    items: items,
    theme: dropdownTheme,
    linkHandler: linkHandler
  }), React__default.createElement(SearchButton, {
    onClick: onSearchClick,
    isActive: hasSearch && !!onSearchClick
  }), isMenuPopupVisible && React__default.createElement(MenuPopup, {
    items: items,
    setExpand: setMenuPopupExpanded,
    isExpanded: menuPopupExpanded,
    headerRef: headerRef,
    linkHandler: linkHandler
  })));
});
export { Header };
